/**
 * Copyright (c) 2013, 2020 Borland Software Corporation, CEA LIST, Artal and others
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Michael Golubev (Montages) - initial API and implementation
 *   Aurelien Didier (ARTAL) - aurelien.didier51@gmail.com - Bug 569174
 *   Etienne Allogo (ARTAL) - etienne.allogo@artal.fr - Bug 569174 : L1.2 clean up
 */
package xpt.plugin;

import com.google.inject.Inject;
import com.google.inject.Singleton;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenApplication;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenEditorGenerator;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenPlugin;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenPropertySheet;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.Extension;
import xpt.propsheet.extensions;

@Singleton
@SuppressWarnings("all")
public class properties {
  @Inject
  @Extension
  private extensions _extensions;
  
  @Inject
  @Extension
  private xpt.providers.extensions _extensions_1;
  
  @Inject
  @Extension
  private impl.actions.extensions _extensions_2;
  
  public CharSequence qualifiedClassName(final GenPlugin it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("plugin.properties");
    return _builder;
  }
  
  public CharSequence fullPath(final GenPlugin it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _qualifiedClassName = this.qualifiedClassName(it);
    _builder.append(_qualifiedClassName);
    return _builder;
  }
  
  public CharSequence properties(final GenPlugin it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _pluginName = this.pluginName(it);
    _builder.append(_pluginName);
    _builder.newLineIfNotEmpty();
    CharSequence _providerName = this.providerName(it);
    _builder.append(_providerName);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _editor = this.editor(it.getEditorGen());
    _builder.append(_editor);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _action = this.action(it.getEditorGen());
    _builder.append(_action);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _application = this.application(it.getEditorGen());
    _builder.append(_application);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    CharSequence _navigator = this.navigator(it.getEditorGen());
    _builder.append(_navigator);
    _builder.newLineIfNotEmpty();
    CharSequence _diagramUpdater = this.diagramUpdater(it.getEditorGen());
    _builder.append(_diagramUpdater);
    _builder.newLineIfNotEmpty();
    _builder.newLine();
    {
      GenPropertySheet _propertySheet = it.getEditorGen().getPropertySheet();
      boolean _tripleNotEquals = (_propertySheet != null);
      if (_tripleNotEquals) {
        CharSequence _i18n = this._extensions.i18n(it.getEditorGen().getPropertySheet());
        _builder.append(_i18n);
      }
    }
    _builder.newLineIfNotEmpty();
    CharSequence _i18n_1 = this._extensions_1.i18n(it.getEditorGen().getDiagram());
    _builder.append(_i18n_1);
    _builder.newLineIfNotEmpty();
    CharSequence _i18n_2 = this._extensions_2.i18n(it.getEditorGen());
    _builder.append(_i18n_2);
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  public CharSequence pluginName(final GenPlugin it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("pluginName=");
    String _name = it.getName();
    _builder.append(_name);
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  public CharSequence providerName(final GenPlugin it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("providerName=");
    String _provider = it.getProvider();
    _builder.append(_provider);
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  public CharSequence action(final GenEditorGenerator it) {
    StringConcatenation _builder = new StringConcatenation();
    {
      boolean _generateInitDiagramAction = it.getDiagram().generateInitDiagramAction();
      if (_generateInitDiagramAction) {
        _builder.append("initDiagramActionLabel=Initialize ");
        String _diagramFileExtension = it.getDiagramFileExtension();
        _builder.append(_diagramFileExtension);
        _builder.append(" diagram file");
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder;
  }
  
  public CharSequence editor(final GenEditorGenerator it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("editorName=");
    String _modelID = it.getModelID();
    _builder.append(_modelID);
    _builder.append(" Diagram Editing");
    _builder.newLineIfNotEmpty();
    _builder.append("context.description=");
    String _modelID_1 = it.getModelID();
    _builder.append(_modelID_1);
    _builder.append(" Diagram Editing");
    _builder.newLineIfNotEmpty();
    _builder.append("context.name=In ");
    String _modelID_2 = it.getModelID();
    _builder.append(_modelID_2);
    _builder.append(" Diagram Editor");
    _builder.newLineIfNotEmpty();
    _builder.append("newWizardName=");
    String _modelID_3 = it.getModelID();
    _builder.append(_modelID_3);
    _builder.append(" Diagram");
    _builder.newLineIfNotEmpty();
    _builder.append("newWizardDesc=Creates ");
    String _modelID_4 = it.getModelID();
    _builder.append(_modelID_4);
    _builder.append(" diagram.");
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  public CharSequence navigator(final GenEditorGenerator it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("navigatorContentName=*.");
    String _diagramFileExtension = it.getDiagramFileExtension();
    _builder.append(_diagramFileExtension);
    _builder.append(" diagram contents");
    _builder.newLineIfNotEmpty();
    {
      if (((null != it.getNavigator()) && it.getNavigator().isGenerateDomainModelNavigator())) {
        _builder.append("domainNavigatorContentName=*.");
        String _domainFileExtension = it.getDomainFileExtension();
        _builder.append(_domainFileExtension);
        _builder.append(" model contents");
        _builder.newLineIfNotEmpty();
      }
    }
    return _builder;
  }
  
  public CharSequence diagramUpdater(final GenEditorGenerator it) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("update.diagram.name=Update ");
    String _modelID = it.getModelID();
    _builder.append(_modelID);
    _builder.append(" diagram");
    _builder.newLineIfNotEmpty();
    _builder.append("update.diagram.description=Perform ");
    String _modelID_1 = it.getModelID();
    _builder.append(_modelID_1);
    _builder.append(" diagram update");
    _builder.newLineIfNotEmpty();
    return _builder;
  }
  
  public CharSequence application(final GenEditorGenerator it) {
    StringConcatenation _builder = new StringConcatenation();
    {
      GenApplication _application = it.getApplication();
      boolean _tripleNotEquals = (null != _application);
      if (_tripleNotEquals) {
        _builder.append("perspectiveName=");
        String _modelID = it.getModelID();
        _builder.append(_modelID);
        _builder.append(" Perspective");
        _builder.newLineIfNotEmpty();
        _builder.append("applicationActionSetLabel=<");
        String _modelID_1 = it.getModelID();
        _builder.append(_modelID_1);
        _builder.append(" Actions");
        _builder.newLineIfNotEmpty();
        _builder.append("newDiagramActionLabel=");
        String _modelID_2 = it.getModelID();
        _builder.append(_modelID_2);
        _builder.append(" Diagram");
        _builder.newLineIfNotEmpty();
        _builder.append("aboutActionLabel=");
        String _modelID_3 = it.getModelID();
        _builder.append(_modelID_3);
        _builder.append(" Diagram About...");
        _builder.newLineIfNotEmpty();
        _builder.append("openURIActionLabel=Open URI...");
        _builder.newLine();
        _builder.append("openURIActionDescription=Open file by URI");
        _builder.newLine();
        _builder.append("openActionLabel=Open...");
        _builder.newLine();
        _builder.append("openActionDescription=Open file");
        _builder.newLine();
      }
    }
    return _builder;
  }
}
